[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]

[vidalia-svn] r4098: It appears I had already implemented support for ACCEPTED_SE (vidalia/trunk/src/vidalia/log)



Author: edmanm
Date: 2009-08-31 17:53:37 -0400 (Mon, 31 Aug 2009)
New Revision: 4098

Modified:
   vidalia/trunk/src/vidalia/log/StatusEventWidget.cpp
   vidalia/trunk/src/vidalia/log/StatusEventWidget.h
Log:

It appears I had already implemented support for
ACCEPTED_SERVER_DESCRIPTOR events even though I didn't think they existed
yet. Go me.


Modified: vidalia/trunk/src/vidalia/log/StatusEventWidget.cpp
===================================================================
--- vidalia/trunk/src/vidalia/log/StatusEventWidget.cpp	2009-08-31 06:24:19 UTC (rev 4097)
+++ vidalia/trunk/src/vidalia/log/StatusEventWidget.cpp	2009-08-31 21:53:37 UTC (rev 4098)
@@ -71,8 +71,8 @@
           this, SLOT(dirPortReachabilityFinished(QHostAddress, quint16, bool)));
   connect(tc, SIGNAL(serverDescriptorRejected(QHostAddress, quint16, QString)),
           this, SLOT(serverDescriptorRejected(QHostAddress, quint16, QString)));
-  connect(tc, SIGNAL(serverDescriptorAccepted()),
-          this, SLOT(serverDescriptorAccepted()));
+  connect(tc, SIGNAL(serverDescriptorAccepted(QHostAddress, quint16)),
+          this, SLOT(serverDescriptorAccepted(QHostAddress, quint16)));
 
   setItemDelegate(new StatusEventItemDelegate(this));
 }
@@ -548,7 +548,8 @@
 }
 
 void
-StatusEventWidget::serverDescriptorAccepted()
+StatusEventWidget::serverDescriptorAccepted(const QHostAddress &ip,
+                                            quint16 port)
 {
   QPixmap icon =
   addBadgeToPixmap(":/images/48x48/preferences-system-networking.png",

Modified: vidalia/trunk/src/vidalia/log/StatusEventWidget.h
===================================================================
--- vidalia/trunk/src/vidalia/log/StatusEventWidget.h	2009-08-31 06:24:19 UTC (rev 4097)
+++ vidalia/trunk/src/vidalia/log/StatusEventWidget.h	2009-08-31 21:53:37 UTC (rev 4098)
@@ -172,10 +172,10 @@
   void serverDescriptorRejected(const QHostAddress &ip, quint16 port,
                                 const QString &reason);
 
   /** Called when at least one directory authority has accepted the user's
    * server descriptor.
    */
-  void serverDescriptorAccepted();
+  void serverDescriptorAccepted(const QHostAddress &ip, quint16 port);
 
 private:
   /** Adds a new status event notification item to the widget. The item will
@@ -172,10 +172,10 @@
                                 const QString &reason);
 
-  /** Called when at least one directory authority has accepted the user's
-   * server descriptor.
+  /** Emitted when the directory authority with IP address <b>ip</b> and
+   * port <b>port</b> accepted the user's server descriptor.
    */